#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-BwtiZz8dAkaLx0pMn9nntC
key:                  ghcide-2.3.0.0-BwtiZz8dAkaLx0pMn9nntC
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  ed83a89f57cea19690ed3e2bbf99d298
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-BwtiZz8dAkaLx0pMn9nntC
depends:
    Diff-1.0-3AwBz9GmeQV7A6ZW8hzFS2 Glob-0.10.2-DNjpKffTdjbBUfLo1OpU0i
    aeson-2.2.2.0-GWc1LmCE0o9Bpe9MYCbSNj array-0.5.6.0
    async-2.2.6-1mBgL12wSAHIlTk64oC4Cy base-4.18.2.1
    base16-bytestring-1.0.2.0-LgOviYpROdp3pOaaXE89pJ binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-49gRYT0muxnE6KNMA9p3wB
    co-log-core-0.3.2.6-F1bOp9QB9805VTDgXHJCq2 containers-0.6.7
    cryptohash-sha1-0.11.101.0-C9K7vFUDWl7Bvh1SLJKgaJ
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    dependent-map-0.4.0.1-4r2r33M4Hn8IKVT3zqYI4X
    dependent-sum-0.7.2.0-IYDE9ygMNly4daACd7u9mg directory-1.3.8.5
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp
    enummapset-0.7.3.0-AvU9PK4taKt7UCWVNUGYoV exceptions-0.10.7
    extra-1.7.16-H2QjO0vfy7Y45ns0T18nV filepath-1.4.300.1
    fingertree-0.1.6.3-Efx4Gg2sZ9U9pBd2p1jbev
    focus-1.0.3.2-EZvooF7Ok2W8aiymJPeglb ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-LOpCg7MejNCFvvIHGxD5Y6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-6SR2pF0LYL0EHHyjvyCYa8
    hashable-1.4.7.0-FDr33SOXd6ZL3RCqzuvond
    hie-bios-0.12.0-KnLKpcZpNhe5P8ejmx0joa
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-Ci0i7CVcnsUDROnPY2V3EL
    hls-graph-2.3.0.0-Fr6dk5d1XkVCukFOa8oqot
    hls-plugin-api-2.3.0.0-G5e0Mvw7soQ6X1SI2DBT4a
    implicit-hie-0.1.4.0-7vxNXq5kxH52PFDRxNO0J
    implicit-hie-cradle-0.5.0.1-F0JJt5ZBnb94KNMH1IPuh1
    lens-5.3.5-9nq7jyjMsxq6VLN3Y7rg0O
    list-t-1.0.5.7-8ctkFMGRkWUBjfbXQc4Kc7
    lsp-2.2.0.0-8mCJDXbMX822Uu8FbqPA1Q
    lsp-types-2.0.2.0-6AEBSXUBTxURbaLhQdmQL mtl-2.3.1
    opentelemetry-0.8.0-55RpOkiUAMU7ONLX0aN0YF
    optparse-applicative-0.18.1.0-1ZOUgEBAg4Z36ZcICQWhpn
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.2-y57O1yX0U1K0S9aBMDJoK
    prettyprinter-ansi-terminal-1.1.4-6VAYBS49qMl9dVuVZ4ho8E
    random-1.2.1.3-J8W47WuTchP2SADTtbNvax
    regex-tdfa-1.3.2.5-9AtY9xoIxga2JrdG942yea
    row-types-1.0.1.2-DjjgTgCw0uhE3N92LlGVsv
    safe-exceptions-0.1.7.4-1VAvwwFmwsSFhjPPlpTl3V
    sorted-list-0.2.3.1-BiH4MyQ61SAAGj0PGoS4uh
    sqlite-simple-0.4.19.0-Lu8JiczirPt1lj2GGaQBcB stm-2.5.1.0
    stm-containers-1.2.1.1-5NmZn2O3uDG5cFDCTrz287
    syb-0.7.3-58j9w6VktxOJyTIsnWy4XC text-2.0.2
    text-rope-0.3-3pA9KxwlRqXIRuWcLtlruw time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-HBz9luDISr2DkipcdISm26
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-A5j6YbVJ6iQ4Gx0hziy0Dr
    vector-0.13.2.0-HIEoUaJKlQrG3qeQBTxJjw

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

